@@ -15,7 +15,9 @@ from polymorphic.models import PolymorphicModel
 import uuid
 import markdown
 from markdown_link_attr_modifier import LinkAttrModifierExtension
+from itertools import groupby
 from pathlib import Path
+from datetime import timedelta
 import os
 
 from ..stock import StockWidget
@@ -219,7 +221,7 @@ class Form(AutoSlugModel):
         if 'model' in self.__dict__: del self.model
         if 'item_model' in self.__dict__: del self.item_model
         
-        self.modified = timezone.now()
+        self.modified, self.completed = timezone.now(), None
         self.save()
     
     def get_available_plugins(self):
@@ -329,6 +331,22 @@ class Form(AutoSlugModel):
         if 'access_enable' in self.options: return self.options['access_enable']
         return None
     
+    def timed_completion(self):
+        if 'timed_completion' in self.options:
+            return self.options['timed_completion']
+        return None
+    
+    def complete_submit_time(self):
+        if 'complete_submit_time' in self.options:
+            return self.options['complete_submit_time']
+        return 5 # minutes
+    
+    def extra_time(self):
+        extra = self.complete_submit_time()
+        if timezone.now() - self.completed <= timedelta(minutes=extra):
+            return True
+        return False
+    
     def markdown(self, text):
         md = self.program.markdown
         return md.reset().convert(text)
@@ -896,6 +914,18 @@ class Submission(models.Model):
     def _submit(self):
         self._submitted = timezone.now()
         self.save()
+    
+    def _collections(self, queryset=None, form=None):
+        if not form: form = self._get_form()
+        if not queryset: queryset = self._items.all()
+        
+        # form's order also orders blocks' items with the same collection name
+        block = FormBlock.objects.filter(form=form, pk=OuterRef('_block'))
+        queryset = queryset.annotate(page=Subquery(block.values('page')))
+        queryset = queryset.annotate(block_rank=Subquery(block.values('_rank')))
+        items = queryset.order_by('_collection', 'page', 'block_rank', '_rank')
+        collections = groupby(items, key=lambda item: item._collection)
+        return { k: list(items) for k, items in collections }
 
 
 def file_path(instance, filename):
